@@ -1,6 +1,6 @@
 package Statocles;
 # ABSTRACT: A static site generator
-$Statocles::VERSION = '0.065';
+$Statocles::VERSION = '0.066';
 # The currently-running site.
 # I hate this, but I know of no better way to ensure that we always have access
 # to a Mojo::Log object, while still being relatively useful, without having to
@@ -28,7 +28,7 @@ Statocles - A static site generator
 
 =head1 VERSION
 
-version 0.065
+version 0.066
 
 =head1 SYNOPSIS
 
@@ -120,7 +120,9 @@ L<Syntax highlighting|Statocles::Plugin::Highlight> for code and configuration b
 =item *
 
 Hooks to add L<your own plugins|Statocles::Plugin> and L<your own custom
-applications|Statocles::App>.  =back
+applications|Statocles::App>.
+
+=back
 
 =head1 GETTING STARTED
 
