@@ -1,6 +1,6 @@
 package Statocles::Document;
 # ABSTRACT: Base class for all Statocles documents
-$Statocles::Document::VERSION = '0.065';
+$Statocles::Document::VERSION = '0.066';
 use Statocles::Base 'Class';
 use Statocles::Image;
 
@@ -12,6 +12,13 @@ has path => (
 );
 
 
+has store => (
+    is => 'ro',
+    isa => Store,
+    coerce => Store->coercion,
+);
+
+
 has title => (
     is => 'rw',
     isa => Str,
@@ -119,7 +126,7 @@ Statocles::Document - Base class for all Statocles documents
 
 =head1 VERSION
 
-version 0.065
+version 0.066
 
 =head1 DESCRIPTION
 
@@ -147,6 +154,11 @@ An example file with frontmatter looks like:
 
 The path to this document. This is not settable from the frontmatter.
 
+=head2 store
+
+The Store this document comes from. This is not settable from the
+frontmatter.
+
 =head2 title
 
     ---
