@@ -1,8 +1,9 @@
 package Statocles::Page;
 # ABSTRACT: Base class for rendering objects
-$Statocles::Page::VERSION = '0.065';
+$Statocles::Page::VERSION = '0.066';
 use Statocles::Base 'Role';
 use Statocles::Template;
+use Statocles::Util qw( uniq_by );
 
 
 has site => (
@@ -189,7 +190,8 @@ sub links {
         push @{ $self->_links->{ $name } }, Link->coerce( $add_link );
         return;
     }
-    my @links = $self->_links->{ $name } ? @{ $self->_links->{ $name } } : ();
+    my @links = uniq_by { $_->href }
+        $self->_links->{ $name } ? @{ $self->_links->{ $name } } : ();
     return wantarray ? @links : $links[0];
 }
 
@@ -227,7 +229,7 @@ Statocles::Page - Base class for rendering objects
 
 =head1 VERSION
 
-version 0.065
+version 0.066
 
 =head1 DESCRIPTION
 
