@@ -1,9 +1,10 @@
 package Statocles::Page::Document;
 # ABSTRACT: Render document objects into HTML
-$Statocles::Page::Document::VERSION = '0.065';
+$Statocles::Page::Document::VERSION = '0.066';
 use Statocles::Base 'Class';
 with 'Statocles::Page';
 use Statocles::Template;
+use Statocles::Store;
 
 
 has document => (
@@ -56,7 +57,12 @@ has '+_images' => (
 sub _render_content_template {
     my ( $self, $content, $vars ) = @_;
     my $tmpl = $self->site->theme->build_template( $self->path, $content );
-    my $rendered = $tmpl->render( %$vars, $self->vars, self => $self->document, page => $self );
+    my $doc = $self->document;
+    if ( $doc->store ) {
+        my $document_path = $doc->store->path->child( $doc->path )->parent;
+        push @{ $tmpl->include_stores }, Statocles::Store->new( path => $document_path );
+    }
+    my $rendered = $tmpl->render( %$vars, $self->vars, self => $doc, page => $self );
     return $rendered;
 }
 
@@ -140,7 +146,7 @@ Statocles::Page::Document - Render document objects into HTML
 
 =head1 VERSION
 
-version 0.065
+version 0.066
 
 =head1 DESCRIPTION
 
