@@ -1,11 +1,12 @@
 package Statocles::Page::List;
 # ABSTRACT: A page presenting a list of other pages
-$Statocles::Page::List::VERSION = '0.065';
+$Statocles::Page::List::VERSION = '0.066';
 use Statocles::Base 'Class';
 with 'Statocles::Page';
 use List::Util qw( reduce );
 use Statocles::Template;
 use Statocles::Page::ListItem;
+use Statocles::Util qw( uniq_by );
 
 
 has _pages => (
@@ -116,6 +117,22 @@ around vars => sub {
     );
 };
 
+
+around links => sub {
+    my ( $orig, $self, @args ) = @_;
+
+    if ( @args > 1 || $args[0] !~ /^(?:stylesheet|script)$/ ) {
+        return $self->$orig( @args );
+    }
+
+    my @links;
+    for my $page ( @{ $self->pages } ) {
+        push @links, $page->links( @args );
+    }
+    push @links, $self->$orig( @args );
+    return uniq_by { $_->href } @links;
+};
+
 1;
 
 __END__
@@ -128,7 +145,7 @@ Statocles::Page::List - A page presenting a list of other pages
 
 =head1 VERSION
 
-version 0.065
+version 0.066
 
 =head1 DESCRIPTION
 
@@ -193,6 +210,17 @@ page first (if any).
 
 Get the template variables for this page.
 
+=head2 links
+
+    my @links = $page->links( $key );
+
+Get the given set of links for this page. See L<the links
+attribute|Statocles::Page/links> for some commonly-used keys.
+
+For List pages, C<stylesheet> and C<script> links are also collected
+from the L<inner pages|/pages>, to ensure that content in those pages
+works correctly.
+
 =head1 AUTHOR
 
 Doug Bell <preaction@cpan.org>
