@@ -1,6 +1,6 @@
 package Statocles::Plugin::Highlight;
 # ABSTRACT: Highlight code and configuration syntax
-$Statocles::Plugin::Highlight::VERSION = '0.065';
+$Statocles::Plugin::Highlight::VERSION = '0.066';
 
 use Statocles::Base 'Class';
 with 'Statocles::Plugin';
@@ -53,6 +53,9 @@ sub highlight {
     # Handle Mojolicious begin/end
     if ( ref $text eq 'CODE' ) {
         $text = $text->();
+        # begin/end starts with a newline, so remove it to prevent too
+        # much top space
+        $text =~ s/^\n//;
     }
 
     # XXX We need to normalize this so that the current page is always
@@ -107,7 +110,7 @@ Statocles::Plugin::Highlight - Highlight code and configuration syntax
 
 =head1 VERSION
 
-version 0.065
+version 0.066
 
 =head1 SYNOPSIS
 
@@ -179,7 +182,7 @@ To highlight a block of code, use C<begin>/C<end>:
     print "Hello, World!\n";
     % end
 
-To highlight an included file, use the C<include> helper:
+To highlight an included file, use the L<include helper|Statocles::Template/include>:
 
     %= highlight Perl => include 'test.pl'
 
