@@ -1,6 +1,6 @@
 package Statocles::Store;
 # ABSTRACT: The source for data documents and files
-$Statocles::Store::VERSION = '0.065';
+$Statocles::Store::VERSION = '0.066';
 use Statocles::Base 'Class';
 use Scalar::Util qw( weaken blessed );
 use Statocles::Document;
@@ -128,7 +128,7 @@ sub read_document {
     my $full_path = $self->path->child( $path );
     my %doc = $self->parse_frontmatter( $full_path, $full_path->slurp_utf8 );
     my $class = $doc{class} ? use_module( delete $doc{class} ) : 'Statocles::Document';
-    return $class->new( %doc, path => $path );
+    return $class->new( %doc, path => $path, store => $self );
 }
 
 
@@ -216,6 +216,7 @@ sub write_document {
 sub _freeze_document {
     my ( $self, $doc ) = @_;
     delete $doc->{path}; # Path should not be in the document
+    delete $doc->{store};
     if ( exists $doc->{date} ) {
         $doc->{date} = $doc->{date}->strftime( $DATETIME_FORMAT );
     }
@@ -312,7 +313,7 @@ Statocles::Store - The source for data documents and files
 
 =head1 VERSION
 
-version 0.065
+version 0.066
 
 =head1 DESCRIPTION
 
