@@ -1,6 +1,6 @@
 package Statocles::Template;
 # ABSTRACT: A template object to pass around
-$Statocles::Template::VERSION = '0.065';
+$Statocles::Template::VERSION = '0.066';
 use Statocles::Base 'Class';
 use Mojo::Template;
 use Scalar::Util qw( blessed );
@@ -32,6 +32,20 @@ has theme => (
     coerce => Theme->coercion,
 );
 
+
+has include_stores => (
+    is => 'ro',
+    isa => ArrayRef[Store],
+    default => sub { [] },
+    coerce => sub {
+        my ( $thing ) = @_;
+        if ( ref $thing eq 'ARRAY' ) {
+            return [ map { Store->coercion->( $_ ) } @$thing ];
+        }
+        return [ Store->coercion->( $thing ) ];
+    },
+);
+
 has _template => (
     is => 'ro',
     isa => InstanceOf['Mojo::Template'],
@@ -92,7 +106,7 @@ sub render {
         # Add default helpers
         local *{"@{[$t->namespace]}::include"} = sub {
             my ( $name, %extra_args ) = @_;
-            my $inner_tmpl = $self->theme->include( $name );
+            my $inner_tmpl = $self->include( $name );
             return $inner_tmpl->render( %args, %extra_args ) || '';
         };
 
@@ -134,6 +148,28 @@ sub _prelude {
 }
 
 
+sub include {
+    my ( $self, @path ) = @_;
+    my $path = Path::Tiny->new( @path );
+
+    my @stores = @{ $self->include_stores };
+    for my $store ( @{ $self->include_stores } ) {
+        if ( $store->has_file( $path ) ) {
+            return $self->theme->build_template( $path, $store->read_file( $path ) );
+        }
+    }
+
+    my $include = eval { $self->theme->include( @path ) };
+    if ( $@ && $@ =~ /^Can not find include/ ) {
+        die qq{Can not find include "$path" in include directories: }
+            . join( ", ", map { sprintf q{"%s"}, $_->path } @stores, @{ $self->theme->include_stores }, $self->theme->store )
+            . "\n";
+    }
+
+    return $include;
+}
+
+
 sub coercion {
     my ( $class ) = @_;
     return sub {
@@ -157,7 +193,7 @@ Statocles::Template - A template object to pass around
 
 =head1 VERSION
 
-version 0.065
+version 0.066
 
 =head1 DESCRIPTION
 
@@ -179,6 +215,12 @@ The path to the file for this template. Optional.
 The theme this template was created from. Used for includes and other
 information.
 
+=head2 include_stores
+
+An array of L<stores|Statocles::Store> to look for includes. Will be
+used in addition to the L<include_stores from the
+Theme|Statocles::Theme/include_stores>.
+
 =head1 METHODS
 
 =head2 BUILDARGS
@@ -192,6 +234,15 @@ Set the default path to something useful for in-memory templates.
 Render this template, passing in %args. Each key in %args will be available as
 a scalar in the template.
 
+=head2 include
+
+    my $tmpl = $tmpl->include( $path );
+    my $tmpl = $tmpl->include( @path_parts );
+
+Get the desired L<template|Statocles::Template> to include based on the given
+C<path> or C<path_parts>. Looks through all the L<include_stores|/include_stores>.
+If nothing is found, looks in the L<theme includes|Statocles::Theme/include>.
+
 =head2 coercion
 
     my $coerce = Statocles::Template->coercion;
@@ -246,6 +297,12 @@ given the same variables as the current template. Optionally, additional
 name-value pairs can be given to the included template. These additional
 template variables override any current variables.
 
+Includes will be searched for in the L<Theme's C<include_stores>
+attribute|Statocles::Theme/include_stores>. For content documents
+rendered by the L<Statocles::Page::Document
+class|Statocles::Page::Document>, this includes the document's parent
+directory.
+
 Including markdown files does not automatically translate them into
 HTML. If you're in a page template or layout template, use the
 L<markdown helper|/markdown> to render the markdown into HTML.
