@@ -1,6 +1,6 @@
 package Statocles::Theme;
 # ABSTRACT: Templates, headers, footers, and navigation
-$Statocles::Theme::VERSION = '0.065';
+$Statocles::Theme::VERSION = '0.066';
 use Statocles::Base 'Class';
 use File::Share qw( dist_dir );
 use Scalar::Util qw( blessed );
@@ -104,13 +104,16 @@ sub include {
     my ( $self, @path ) = @_;
     my $path = Path::Tiny->new( @path );
 
-    for my $store ( @{ $self->include_stores }, $self->store ) {
+    my @stores = ( @{ $self->include_stores }, $self->store );
+    for my $store ( @stores ) {
         if ( $store->has_file( $path ) ) {
             return $self->_includes->{ $path } ||= $self->build_template( $path, $store->read_file( $path ) );
         }
     }
 
-    die qq{Can not find include "$path"};
+    die qq{Can not find include "$path" in include directories: }
+        . join( ", ", map { sprintf q{"%s"}, $_->path } @stores )
+        . "\n";
 }
 
 
@@ -147,7 +150,7 @@ Statocles::Theme - Templates, headers, footers, and navigation
 
 =head1 VERSION
 
-version 0.065
+version 0.066
 
 =head1 SYNOPSIS
 
@@ -242,7 +245,11 @@ L<include_stores|/include_stores> before looking in the L<main store|/store>.
 
 Register a helper on this theme. Helpers are functions that are added to
 the template to allow for additional features. Helpers are usually added
-by plugins.
+by L<Statocles plugins|Statocles::Plugin>.
+
+There are a L<default set of helpers available to all
+templates|Statocles::Template/DEFAULT HELPERS> which cannot be
+overridden by this method.
 
 =head2 clear
 
