@@ -1,11 +1,11 @@
 package Statocles::Util;
 # ABSTRACT: Various utility functions to reduce dependencies
-$Statocles::Util::VERSION = '0.065';
+$Statocles::Util::VERSION = '0.066';
 use Statocles::Base;
 use Exporter 'import';
 
 our @EXPORT_OK = qw(
-    dircopy run_editor
+    dircopy run_editor uniq_by
 );
 
 
@@ -44,6 +44,17 @@ sub run_editor {
     return 1;
 }
 
+
+sub uniq_by(&@) {
+    my ( $sub, @list ) = @_;
+    my ( %found, @out );
+    for my $i ( @list ) {
+        local $_ = $i;
+        push @out, $i if !$found{ $sub->() }++;
+    }
+    return @out;
+}
+
 1;
 
 __END__
@@ -56,7 +67,7 @@ Statocles::Util - Various utility functions to reduce dependencies
 
 =head1 VERSION
 
-version 0.065
+version 0.066
 
 =head1 SYNOPSIS
 
@@ -85,6 +96,13 @@ the given path. Returns true if an editor was invoked, false otherwise. If the
 editor was not able to be invoked (C<EDITOR> was set but could not be run), an
 exception is thrown.
 
+=head2 uniq_by
+
+    my @uniq_links = uniq_by { $_->href } @links;
+
+Filter a list into its unique items based on the result of the passed-in block.
+This lets us get unique links from their C<href> attribute.
+
 =head1 AUTHOR
 
 Doug Bell <preaction@cpan.org>
